
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class YuncengFlutterPlugin {
    static const int _pluginErrorChannel = -1000;

    static const String _tag = "YunCengPlugin";
    static const MethodChannel _channel = MethodChannel('yunceng_flutter_plugin');

    static Future<int> initEx(String appKey, String token) async {
        int ret;
        try {
            dynamic arguments = {
                'app_key':appKey, 
                'token':token,
            };
            ret = await _channel.invokeMethod('initEx', arguments);
        } on Exception catch(e) {
             debugPrint("$_tag init failed: '${e.toString()}'");
             ret = _pluginErrorChannel;
        }
        return ret;
    }

    static Future<YuncengResult> getProxyTcpByDomain(String token, String groupName, String domain, String port) async {
        YuncengResult result;
        try {
            dynamic arguments = {
                'token': token, 
                'group_name': groupName, 
                'domain': domain,
                'port': port,
            };
            Map<dynamic, dynamic>? map = await _channel.invokeMapMethod('getProxyTcpByDomain', arguments);
            result = YuncengResult(map?.cast()['ret'], map?.cast()['ip'], map?.cast()['port']);
        } on Exception catch(e) {
            debugPrint("$_tag init failed: '${e.toString()}'");
            result = YuncengResult(_pluginErrorChannel, '', '');
        }
        return result;
    }
}

class YuncengResult {
    int ret = 0;
    String ip = '';
    String port = '';

    YuncengResult(this.ret, this.ip, this.port);
}